/* This example uses the AStar32U4Buzzer class to play a
series of notes on the buzzer.

This example demonstrates the use of the playFrequency(),
playNote(), and playFromProgramSpace() functions, which play
entirely in the background, requiring no further action from
the user once the function is called.  The CPU is then free
to execute other code while the buzzer plays.

This example also shows how to use the stopPlaying()
function to stop the buzzer, and it shows how to use the
isPlaying() function to tell whether the buzzer is still
playing or not.

For this example to work, you will need to have a buzzer
soldered into the A-Star, and you will need to install a
shorting block on the two pins near the buzzer, which will
connect pin 6 to the buzzer.

Note: This demo uses pin 6 to control the buzzer. To avoid
damage or improper operation, if you have shields or other
electronics connected, make sure they do not use that pin in
a conflicting way. */

#include <AStar32U4.h>

AStar32U4Buzzer buzzer;

// Store this song in program space using the PROGMEM macro.
// Later we will play it directly from program space,
// bypassing the need to load it all into RAM first.
const char fugue[] PROGMEM =
  "! O5 L16 agafaea dac+adaea fa<aa<bac#a dac#adaea f"
  "O6 dcd<b-d<ad<g d<f+d<gd<ad<b- d<dd<ed<f+d<g d<f+d<gd<ad"
  "L8 MS <b-d<b-d MLe-<ge-<g MSc<ac<a ML d<fd<f O5 MS b-gb-g"
  "ML >c#e>c#e MS afaf ML gc#gc# MS fdfd ML e<b-e<b-"
  "O6 L16ragafaea dac#adaea fa<aa<bac#a dac#adaea faeadaca"
  "<b-acadg<b-g egdgcg<b-g <ag<b-gcf<af dfcf<b-f<af"
  "<gf<af<b-e<ge c#e<b-e<ae<ge <fe<ge<ad<fd"
  "O5 e>ee>ef>df>d b->c#b->c#a>df>d e>ee>ef>df>d"
  "e>d>c#>db>d>c#b >c#agaegfe f O6 dc#dfdc#<b c#4";

void setup()       // run once, when the sketch starts
{
}

void loop()        // run over and over again
{
  // Start playing a tone with frequency 440 Hz at maximum
  // volume (15) for 200 milliseconds.
  buzzer.playFrequency(440, 200, 15);

  // Delay to give the tone time to finish.
  delay(1000);

  // Start playing note A in octave 4 at maximum volume
  // volume (15) for 2000 milliseconds.
  buzzer.playNote(NOTE_A(4), 2000, 15);

  // Wait for 200 ms and stop playing note.
  delay(200);
  buzzer.stopPlaying();

  delay(1000);

  // Start playing a fugue from program space.
  buzzer.playFromProgramSpace(fugue);

  // Wait until it is done playing.
  while(buzzer.isPlaying()){ }

  delay(1000);
}
